@@ -1,6 +1,6 @@
 import $ from 'jquery'
 
-let Navbar = {
+const Navbar = {
   /**
    * Navbar component
    *
@@ -19,8 +19,8 @@ let Navbar = {
     // insert burger
     $('#branding').before(
       $('<button/>', {
-        'class': 'navbar-toggler navbar-toggler-right',
-        'data-toggle': 'collapse'
+        class: 'navbar-toggler navbar-toggler-right',
+        'data-bs-toggle': 'collapse'
       }).html('<i class="fa fa-bars"></i>')
         .click(() => $(document.body).addClass('menu-open')))
     // remove only text
@@ -29,15 +29,24 @@ let Navbar = {
         return (this.nodeType === 3)
       }).remove()
     // dropdown
-    let dropdown = $('<div/>', { 'class': 'dropdown' }).appendTo($('#user-tools'))
-    let dropdownMenu = $('<div/>', { 'class': 'dropdown-menu dropdown-menu-right' }).appendTo(dropdown)
+    const dropdown = $('<div/>', { class: 'dropdown' }).appendTo($('#user-tools'))
+    const dropdownMenu = $('<div/>', { class: 'dropdown-menu dropdown-menu-right' }).appendTo(dropdown)
     $('#user-tools strong')
       .addClass('dropdown-toggle btn btn-default')
-      .attr('data-toggle', 'dropdown')
+      .attr('data-bs-toggle', 'dropdown')
       .prependTo(dropdown)
     // @TODO find a way to mv view site from dropdown
     // password change view doesn't have it so breaks things
     $('#user-tools  > a').addClass('dropdown-item').appendTo(dropdownMenu)
+
+    // django 4.1 logout form
+    if ($('#logout-form').length) {
+      $('#logout-form button').css('display', 'none')
+      $('<a />', { class: 'dropdown-item', 'data-item': 'logout' })
+        .html($('#logout-form button').html())
+        .on('click', function () { $('#logout-form').submit() })
+        .appendTo(dropdownMenu)
+    }
   }
 }
 
