@@ -1,11 +1,11 @@
-from django.conf.urls import url
+from django.urls import path
 
 from .views import GetAppListJsonView, GetGravatartUrlJsonView
 
 
 urlpatterns = [
-    url(r'^app-list-json/$', GetAppListJsonView.as_view(),
+    path('app-list-json/', GetAppListJsonView.as_view(),
         name='baton-app-list-json'),
-    url(r'^gravatar/$', GetGravatartUrlJsonView.as_view(),
+    path('gravatar/', GetGravatartUrlJsonView.as_view(),
         name='baton-gravatar-json'),
 ]
